#!/bin/bash
#
# Note that gccxml is an executable, 
# so we do not normally build debug or opt versions.

# buildGccxml.sh [gcc47|gcc46]
# default is gcc47

basequal=${1}

if [ -z ${basequal} ]
then
    basequal=gcc47
fi

pkgver=v0_9_20130503

fullqual=${basequal}
qualdir=${basequal}

if [ "${basequal}" = "gcc47" ]
then
   gccdotver=4.7
   gccver=v4_7_1
else
   gccdotver=4.6
   gccver=v4_6_1
fi

echo "compiling for ${fullqual}"

source ${PRODUCTS}/setup
OS=`uname`
if [ ${OS} = "Darwin" ]
then
    flvr=`ups flavor -2`
else
    flvr=`ups flavor`
fi
pkgdir=${PRODUCTS}/gccxml/${pkgver}/${flvr}-${qualdir}
gccxmlhead=${PRODUCTS}/gccxml/${pkgver}

setup cmake

if [ -z ${flvr} ]
then
   echo "ERROR: could not determine flavor for this platform"
   echo "       something is very wrong"
   exit 1
fi

# setup gcc
setup gcc ${gccver}
gccshortver=`gcc --version | head -1 | cut -f3 -d" " | cut -f1-2 -d"."`
gccfullver=`gcc --version | head -1 | cut -f3 -d" "`
if [ ${gccshortver} = ${gccdotver} ]
then
  echo " OK - gcc version is ${gccfullver}"
else
  echo "ERROR: wrong gcc version ${gccfullver}"
  exit 1
fi

mkdir -p ${pkgdir}/build
if [ ! -d ${pkgdir}/build ]
then
   echo "ERROR: failed to create ${pkgdir}/build"
   exit 1
fi

set -x

cd ${pkgdir}/build
cmake -DCMAKE_INSTALL_PREFIX=${pkgdir} ${gccxmlhead}/source/gccxml
make 
make test
make install 

set +x

if [ ! -d ${pkgdir}/bin ]
then
   echo "ERROR: failed to create ${pkgdir}/bin"
   echo "       Something is very wrong"
   exit 1
fi

# this should not complain
   echo "Finished building gccxml for flavor ${flvr}"
   echo "Declaring gccxml ${pkgver} -q ${fullqual} "
OS=`uname`
if [ ${OS} = "Darwin" ]
then
   ups declare gccxml ${pkgver} -r gccxml/${pkgver} -2 -m gccxml.table -q ${fullqual}
else 
   ups declare gccxml ${pkgver} -r gccxml/${pkgver} -4 -m gccxml.table -q ${fullqual}
fi
setup gccxml ${pkgver} -q ${fullqual}
which gccxml

# fix share/gccxml-0.9/gccxml_config
mv ${GCCXML_FQ_DIR}/share/gccxml-0.9/gccxml_config ${GCCXML_FQ_DIR}/share/gccxml-0.9/gccxml_config.bak
cat ${GCCXML_FQ_DIR}/share/gccxml-0.9/gccxml_config.bak | sed 's%^GCCXML_COMPILER=.*$%GCCXML_COMPILER=${GCC_FQ_DIR}/bin/c++%' > ${GCCXML_FQ_DIR}/share/gccxml-0.9/gccxml_config

exit 0

